urls = {
    "start": "http://",
    "status": ":9006/as/system/status",
    "info_url": ":9006/as/system/information",
    "rec_list": ":9006/as/pvr?limit=1000&offset=0",
    "rec_info": ":9006/as/pvr/details/{0}",
    "chn_list": "http://awk.epgsky.com/hawk/linear/schedule/{0}/{1}",
    "channel_epg": ":9006/as/services",
    "channel_info": "9006/as/service/details/{0}",
    "metadata_url": "https://images.metadata.sky.com/pd-image/{0}/16-9?sid={1}",
    'xml_base': 'https://www.xmltv.co.uk'
}

commands = {
    "power": 0,
    "select": 1,
    "backup": 2,
    "dismiss": 2,
    "channelup": 6,
    "channeldown": 7,
    "interactive": 8,
    "sidebar": 8,
    "help": 9,
    "services": 10,
    "search": 10,
    "tvguide": 11,
    "home": 11,
    "i": 14,
    "text": 15,
    "up": 16,
    "down": 17,
    "left": 18,
    "right": 19,
    "red": 32,
    "green": 33,
    "yellow": 34,
    "blue": 35,
    "0": 48,
    "1": 49,
    "2": 50,
    "3": 51,
    "4": 52,
    "5": 53,
    "6": 54,
    "7": 55,
    "8": 56,
    "9": 57,
    "play": 64,
    "pause": 65,
    "stop": 66,
    "record": 67,
    "fastforward": 69,
    "rewind": 71,
    "boxoffice": 240,
    "sky": 241
}
dict_channel_list = None
port = 49160,
search_timeout = 5
